HYSurveyView class

sdk public HY Survey View for embedded integration

Inheritance

Constructors

HYSurveyView({Key? key, String sendId = "", String surveyId = "", String channelId = "", VoidCallback? onCancel, VoidCallback? onSubmit, ErrorCallback? onError, VoidCallback? onClose, bool debug = false, Map<String, dynamic> parameters = const {}, Map<String, dynamic> options = const {}})
const

Properties

channelId → String
final
debug → bool
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onCancel → VoidCallback?
final
onClose → VoidCallback?
final
onError → ErrorCallback?
final
onSubmit → VoidCallback?
final
options → Map<String, dynamic>
final
parameters → Map<String, dynamic>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sendId → String
final
surveyId → String
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<HYSurveyView>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited